@@ -16,7 +16,6 @@ runner type.
 from __future__ import absolute_import
 
 import enum
-from typing import Dict, List  # noqa ignore=F401 imported but unused
 
 from sagemaker_training import environment, mpi, params, process
 
@@ -33,7 +32,6 @@ MPIRunnerType = RunnerType.MPI
 
 
 def get(identifier, user_entry_point=None, args=None, env_vars=None, extra_opts=None):
-    # type: (RunnerType, str, List[str], Dict[str]) -> process.Runner
     """Get the process runner based on the runner type.
 
     Args:
